@@ -22,11 +22,12 @@ class ConfigInitUseCase:
         """Initialize app configuration."""
         try:
             new_github_service = ghs.GithubService(request)
-        except AttributeError:
-            return res.ResponseFailure.build_parameters_error()
+        except AttributeError as ae:
+            return res.ResponseFailure.build_parameters_error(f"{ae}")
         except ConnectionError:
             return res.ResponseFailure.build_system_error()
         repo_names = new_github_service.get_repo_names()
+        config = new_github_service.get_config()
         selected_repos = p.InquirerPrompter.select_repos(repo_names)
-        cr.ConfigReposUseCase(self.config_manager).execute(selected_repos)
+        cr.ConfigReposUseCase(self.config_manager).execute(config, selected_repos)
         return res.ResponseSuccess("gitp successfully configured.")
